@@ -3,6 +3,7 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
+
 /* include this first, before NO_IMPORT_PYGOBJECT is defined */
 #include <pygobject.h>
 #include "pygtk-private.h"
@@ -18,12 +19,6 @@ extern PyMethodDef pygdk_functions[];
 
 static struct _PyGtk_FunctionStruct functions = {
     VERSION,
-    FALSE,
-
-    pygtk_block_threads,
-    pygtk_unblock_threads,
-
-    pygtk_destroy_notify,
 
     &PyGdkAtom_Type,  PyGdkAtom_New,
 };
@@ -31,7 +26,7 @@ static struct _PyGtk_FunctionStruct functions = {
 DL_EXPORT(void)
 init_gtk(void)
 {
-    PyObject *m, *d, *v, *tuple;
+    PyObject *m, *d, *tuple;
     PyObject *av;
     int argc, i;
     char **argv;
@@ -41,13 +36,6 @@ init_gtk(void)
     /* initialise gobject */
     init_pygobject();
 
-    /* initialise gthread if appropriate ... */
-#ifdef ENABLE_PYGTK_THREADING
-    /* it is required that this function be called to enable the thread
-     * safety functions */
-    g_thread_init(NULL);
-#endif
-
     /* set the default python encoding to utf-8 */
     PyUnicode_SetDefaultEncoding("utf-8");
 
@@ -63,7 +51,7 @@ init_gtk(void)
 		g_free(argv[i]);
 	    g_free(argv);
 	}
-	Py_FatalError("could not open display");
+	PyErr_SetString(PyExc_RuntimeError, "could not open display");
 	return;
     }
     PySys_SetArgv(argc, argv);
